@@ -40,13 +40,14 @@ class StructureScore(BaseEstimator):
 
     def score(self, model):
         """
-        Computes a score to measure how well the given `BayesianModel` fits to the data set.
-        (This method relies on the `local_score`-method that is implemented in each subclass.)
+        Computes a score to measure how well the given `BayesianNetwork` fits
+        to the data set.  (This method relies on the `local_score`-method that
+        is implemented in each subclass.)
 
         Parameters
         ----------
-        model: `BayesianModel` instance
-            The Bayesian network that is to be scored. Nodes of the BayesianModel need to coincide
+        model: BayesianNetwork instance
+            The Bayesian network that is to be scored. Nodes of the BayesianNetwork need to coincide
             with column names of data set.
 
         Returns
@@ -58,14 +59,14 @@ class StructureScore(BaseEstimator):
         --------
         >>> import pandas as pd
         >>> import numpy as np
-        >>> from pgmpy.models import BayesianModel
+        >>> from pgmpy.models import BayesianNetwork
         >>> from pgmpy.estimators import K2Score
         >>> # create random data sample with 3 variables, where B and C are identical:
         >>> data = pd.DataFrame(np.random.randint(0, 5, size=(5000, 2)), columns=list('AB'))
         >>> data['C'] = data['B']
-        >>> K2Score(data).score(BayesianModel([['A','B'], ['A','C']]))
+        >>> K2Score(data).score(BayesianNetwork([['A','B'], ['A','C']]))
         -24242.367348745247
-        >>> K2Score(data).score(BayesianModel([['A','B'], ['B','C']]))
+        >>> K2Score(data).score(BayesianNetwork([['A','B'], ['B','C']]))
         -16273.793897051042
         """
 
@@ -88,7 +89,7 @@ class StructureScore(BaseEstimator):
 class K2Score(StructureScore):
     def __init__(self, data, **kwargs):
         """
-        Class for Bayesian structure scoring for BayesianModels with Dirichlet priors.
+        Class for Bayesian structure scoring for BayesianNetworks with Dirichlet priors.
         The K2 score is the result of setting all Dirichlet hyperparameters/pseudo_counts to 1.
         The `score`-method measures how well a model is able to describe the given data set.
 
@@ -129,13 +130,13 @@ class K2Score(StructureScore):
         num_parents_states = float(state_counts.shape[1])
 
         counts = np.asarray(state_counts)
-        log_gamma_counts = np.zeros_like(counts, dtype=np.float_)
+        log_gamma_counts = np.zeros_like(counts, dtype=float)
 
         # Compute log(gamma(counts + 1))
         gammaln(counts + 1, out=log_gamma_counts)
 
         # Compute the log-gamma conditional sample size
-        log_gamma_conds = np.sum(counts, axis=0, dtype=np.float_)
+        log_gamma_conds = np.sum(counts, axis=0, dtype=float)
         gammaln(log_gamma_conds + var_cardinality, out=log_gamma_conds)
 
         score = (
@@ -150,7 +151,7 @@ class K2Score(StructureScore):
 class BDeuScore(StructureScore):
     def __init__(self, data, equivalent_sample_size=10, **kwargs):
         """
-        Class for Bayesian structure scoring for BayesianModels with Dirichlet priors.
+        Class for Bayesian structure scoring for BayesianNetworks with Dirichlet priors.
         The BDeu score is the result of setting all Dirichlet hyperparameters/pseudo_counts to
         `equivalent_sample_size/variable_cardinality`.
         The `score`-method measures how well a model is able to describe the given data set.
@@ -200,14 +201,14 @@ class BDeuScore(StructureScore):
         num_parents_states = self.get_number_of_parent_states(state_counts)
 
         counts = np.asarray(state_counts)
-        log_gamma_counts = np.zeros_like(counts, dtype=np.float_)
+        log_gamma_counts = np.zeros_like(counts, dtype=float)
         alpha = self.equivalent_sample_size / num_parents_states
         beta = self.equivalent_sample_size / counts.size
         # Compute log(gamma(counts + beta))
         gammaln(counts + beta, out=log_gamma_counts)
 
         # Compute the log-gamma conditional sample size
-        log_gamma_conds = np.sum(counts, axis=0, dtype=np.float_)
+        log_gamma_conds = np.sum(counts, axis=0, dtype=float)
         gammaln(log_gamma_conds + alpha, out=log_gamma_conds)
 
         score = (
@@ -222,11 +223,14 @@ class BDeuScore(StructureScore):
 class BDsScore(BDeuScore):
     def __init__(self, data, equivalent_sample_size=10, **kwargs):
         """
-        Class for Bayesian structure scoring for BayesianModels with Dirichlet priors.
-        The BDs score is the result of setting all Dirichlet hyperparameters/pseudo_counts to
-        `equivalent_sample_size/modified_variable_cardinality` where for the modified_variable_cardinality
-        only the number of parent configurations where there were observed variable counts are considered.
-        The `score`-method measures how well a model is able to describe the given data set.
+        Class for Bayesian structure scoring for BayesianNetworks with
+        Dirichlet priors.  The BDs score is the result of setting all Dirichlet
+        hyperparameters/pseudo_counts to
+        `equivalent_sample_size/modified_variable_cardinality` where for the
+        modified_variable_cardinality only the number of parent configurations
+        where there were observed variable counts are considered.  The
+        `score`-method measures how well a model is able to describe the given
+        data set.
 
         Parameters
         ----------
@@ -287,10 +291,12 @@ class BDsScore(BDeuScore):
 class BicScore(StructureScore):
     def __init__(self, data, **kwargs):
         """
-        Class for Bayesian structure scoring for BayesianModels with Dirichlet priors.
-        The BIC/MDL score ("Bayesian Information Criterion", also "Minimal Descriptive Length") is a
-        log-likelihood score with an additional penalty for network complexity, to avoid overfitting.
-        The `score`-method measures how well a model is able to describe the given data set.
+        Class for Bayesian structure scoring for BayesianNetworks with
+        Dirichlet priors.  The BIC/MDL score ("Bayesian Information Criterion",
+        also "Minimal Descriptive Length") is a log-likelihood score with an
+        additional penalty for network complexity, to avoid overfitting.  The
+        `score`-method measures how well a model is able to describe the given
+        data set.
 
         Parameters
         ----------
@@ -330,13 +336,13 @@ class BicScore(StructureScore):
         num_parents_states = float(state_counts.shape[1])
 
         counts = np.asarray(state_counts)
-        log_likelihoods = np.zeros_like(counts, dtype=np.float_)
+        log_likelihoods = np.zeros_like(counts, dtype=float)
 
         # Compute the log-counts
         np.log(counts, out=log_likelihoods, where=counts > 0)
 
         # Compute the log-conditional sample size
-        log_conditionals = np.sum(counts, axis=0, dtype=np.float_)
+        log_conditionals = np.sum(counts, axis=0, dtype=float)
         np.log(log_conditionals, out=log_conditionals, where=log_conditionals > 0)
 
         # Compute the log-likelihoods
