@@ -64,8 +64,8 @@ class DBNInference(Inference):
         start_markov_model = self.start_bayesian_model.to_markov_model()
         one_and_half_markov_model = self.one_and_half_model.to_markov_model()
 
-        combinations_slice_0 = tee(combinations(self.interface_nodes_0, 2), 2)
-        combinations_slice_1 = combinations(self.interface_nodes_1, 2)
+        combinations_slice_0 = tee(combinations(set(self.interface_nodes_0), 2), 2)
+        combinations_slice_1 = combinations(set(self.interface_nodes_1), 2)
 
         start_markov_model.add_edges_from(combinations_slice_0[0])
         one_and_half_markov_model.add_edges_from(
